@@ -141,6 +141,12 @@ setMethod("reclass_timespan", signature(orig = "Period"), function(new, orig){
 #' one normal year. For an exact 
 #' transformation, first transform the period to an interval with 
 #' \code{\link{as.interval}}.
+#' 
+#' as.duration.period displays the message "estimate only: 
+#' convert periods to 
+#' intervals for accuracy" by default. You can turn this message off by 
+#' setting the global \code{lubridate.verbose} option to FALSE with 
+#' \code{options(lubridate.verbose = FALSE)}.
 #'
 #' @param x Object to be coerced to a duration  
 #' @return A duration object
@@ -155,6 +161,7 @@ setMethod("reclass_timespan", signature(orig = "Period"), function(new, orig){
 #' # 10s
 #' @export 
 #' @aliases as.duration,numeric-method
+#' @aliases as.duration,logical-method
 #' @aliases as.duration,difftime-method
 #' @aliases as.duration,Interval-method
 #' @aliases as.duration,Duration-method
@@ -168,6 +175,10 @@ setMethod("as.duration", signature(x = "numeric"), function(x){
 	new("Duration", x)
 })
 
+setMethod("as.duration", signature(x = "logical"), function(x){
+  new("Duration", as.numeric(x))
+})
+
 setMethod("as.duration", signature(x = "difftime"), function(x){
 	new("Duration", as.numeric(x, "secs"))
 })
@@ -181,7 +192,10 @@ setMethod("as.duration", signature(x = "Duration"), function(x){
 })
 
 setMethod("as.duration", signature(x = "Period"), function(x){
-	message("estimate only: convert periods to intervals for accuracy")
+  verbose <- getOption("lubridate.verbose")
+  if (is.null(verbose) || verbose) {
+    message("estimate only: convert periods to intervals for accuracy")
+  }
 	new("Duration", period_to_seconds(x))
 })
 
@@ -209,6 +223,7 @@ setMethod("as.duration", signature(x = "Period"), function(x){
 #' @export as.interval
 #' @param x a duration, difftime, period, or numeric object that describes the length of the interval
 #' @param start a POSIXt or Date object that describes when the interval begins   
+#' @param ... additional arguments to pass to as.interval
 #' @return an interval object
 #' @seealso \code{\link{interval}}, \code{\link{new_interval}}
 #' @keywords classes manip methods chron
@@ -233,8 +248,44 @@ setMethod("as.duration", signature(x = "Period"), function(x){
 #'
 #' as.interval(3600, ymd("2009-01-01")) #numeric
 #' # 2009-01-01 UTC--2009-01-01 01:00:00 UTC
-as.interval <- function(x, start){
-	stopifnot(is.instant(start))
+#' @aliases as.interval,numeric-method
+#' @aliases as.interval,difftime-method
+#' @aliases as.interval,Interval-method
+#' @aliases as.interval,Duration-method
+#' @aliases as.interval,Period-method
+#' @aliases as.interval,POSIXt-method
+#' @aliases as.interval,logical-method
+as.interval <- function(x, start, ...) standardGeneric("as.interval")
+
+#' @export
+setGeneric("as.interval")
+
+setMethod("as.interval", signature(x = "numeric"), function(x, start, ...){
+  .number_to_interval(x, start, ...)
+})
+
+setMethod("as.interval", signature(x = "difftime"), function(x, start, ...){
+  .number_to_interval(x, start, ...)
+})
+
+setMethod("as.interval", signature(x = "Interval"), function(x, start, ...) {
+  x
+})
+
+setMethod("as.interval", signature(x = "POSIXt"), function(x, start, ...) {
+  .number_to_interval(x, start, ...)
+})
+
+#' @export
+setMethod("as.interval", signature("logical"), function(x, start, ...) {
+  .number_to_interval(as.numeric(x), start, ...)
+})
+
+.number_to_interval <- function(x, start, ...){
+  if (missing(start) & all(is.na(x)))
+    start <- as.POSIXct(NA, origin = origin)
+  else stopifnot(is.instant(start))
+  
 	if (is.instant(x))
 		return(new_interval(x, start))
 	else
@@ -265,6 +316,23 @@ as.interval <- function(x, start){
 #' with a months unit can not be coerced from a duration object. For an exact 
 #' transformation, first transform the duration to an interval with 
 #' \code{\link{as.interval}}.
+#' 
+#' Coercing an interval to a period may cause surprising behavior if you request 
+#' periods with small units. A leap year is 366 days long, but one year long. Such 
+#' an interval will convert to 366 days when unit is set to days and 1 year when 
+#' unit is set to years. Adding 366 days to a date will often give a different 
+#' result than adding one year. Daylight savings is the one exception where this 
+#' does not apply. Interval lengths are calculated on the UTC timeline, which does 
+#' not use daylight savings. Hence, periods converted with seconds or minutes will not 
+#' reflect the actual variation in seconds and minutes that occurs due to daylight 
+#' savings. These periods will show the "naive" change in seconds and minutes that is 
+#' suggested by the differences in clock time. See the examples below.
+#'
+#' as.period.difftime and as.period.duration display the message "estimate only: 
+#' convert difftimes (or duration) to 
+#' intervals for accuracy" by default. You can turn this message off by 
+#' setting the global \code{lubridate.verbose} option to FALSE with 
+#' \code{options(lubridate.verbose = FALSE)}.
 #'
 #' @export
 #' @param x an interval, difftime, or numeric object   
@@ -283,11 +351,25 @@ as.interval <- function(x, start){
 #' # "1y 1m 1d 1H 1M 1S"
 #' as.period(span, units = "day")
 #' "397d 1H 1M 1S"
+#' leap <- new_interval(ymd("2016-01-01"), ymd("2017-01-01"))
+#' # 2016-01-01 UTC--2017-01-01 UTC
+#' as.period(leap, unit = "days")
+#' # "366d 0H 0M 0S"
+#' as.period(leap, unit = "years")
+#' # "1y 0m 0d 0H 0M 0S"
+#' dst <- new_interval(ymd("2016-11-06", tz = "America/Chicago"), 
+#' ymd("2016-11-07", tz = "America/Chicago"))
+#' # 2016-11-06 CDT--2016-11-07 CST
+#' # as.period(dst, unit = "seconds")
+#' # "86400S"
+#' as.period(dst, unit = "hours")
+#' # "24H 0M 0S"
 #' @aliases as.period,numeric-method
 #' @aliases as.period,difftime-method
 #' @aliases as.period,Interval-method
 #' @aliases as.period,Duration-method
 #' @aliases as.period,Period-method
+#' @aliases as.period,logical-method
 as.period <- function(x, unit, ...) standardGeneric("as.period")
 
 #' @export
@@ -295,35 +377,22 @@ setGeneric("as.period")
 
 setMethod("as.period", signature(x = "numeric"), function(x, unit = "second", ...){
   x <- as.numeric(x)
+  if (missing(unit)) unit <- "second"
   unit <- standardise_date_names(unit)
   f <- match.fun(paste(unit, "s", sep = ""))
   f(x)
 })
 
 setMethod("as.period", signature(x = "difftime"), function(x, unit = NULL, ...){
-  message("estimate only: convert difftimes to intervals for accuracy")
-  span <- as.double(x, "secs")
-  remainder <- abs(span)
-  newper <- new_period(second = rep(0, length(x)))
-  
-  slot(newper, "year") <- remainder %/% (3600 * 24 * 365.25)
-  remainder <- remainder %% (3600 * 24 * 365.25)
-  
-  slot(newper,"day") <- remainder %/% (3600 * 24)
-  remainder <- remainder %% (3600 * 24)
-  
-  slot(newper, "hour") <- remainder %/% (3600)
-  remainder <- remainder %% (3600)
-  
-  slot(newper, "minute") <- remainder %/% (60)
-  
-  slot(newper, ".Data") <- remainder %% (60)
-  
-  newper * sign(span)
+  verbose <- getOption("lubridate.verbose")
+  if (is.null(verbose) || verbose) {
+    message("estimate only: convert difftimes to intervals for accuracy")
+  }
+  seconds_to_period(as.double(x, "secs"))
 })
 
 setMethod("as.period", signature(x = "Interval"), function(x, unit = NULL, ...) {
-  negs <- int_length(x) < 0
+  negs <- int_length(x) < 0 & !is.na(int_length(x))
   x[negs] <- int_flip(x[negs])
 
   if (is.null(match.call()$unit)) {
@@ -355,19 +424,19 @@ setMethod("as.period", signature(x = "Interval"), function(x, unit = NULL, ...)
   to.per <- to.per[1:6]
   
   # remove negative periods
-  nsecs <- to.per$second < 0
+  nsecs <- to.per$second < 0 & !is.na(to.per$second)
   to.per$second[nsecs] <- 60 + to.per$second[nsecs]
   to.per$minute[nsecs] <- to.per$minute[nsecs] - 1
   
-  nmins <- to.per$minute < 0
+  nmins <- to.per$minute < 0 & !is.na(to.per$minute)
   to.per$minute[nmins] <- 60 + to.per$minute[nmins]
   to.per$hour[nmins] <- to.per$hour[nmins] - 1
   
-  nhous <- to.per$hour < 0
+  nhous <- to.per$hour < 0 & !is.na(to.per$hour)
   to.per$hour[nhous] <- 24 + to.per$hour[nhous]
   to.per$day[nhous] <- to.per$day[nhous] - 1
   
-  ndays <- to.per$day < 0
+  ndays <- to.per$day < 0 & !is.na(to.per$day)
   if (any(ndays)) {
     day.no <- floor_date(end, "month") - days(1)
     day.no <- day.no$mday
@@ -375,7 +444,7 @@ setMethod("as.period", signature(x = "Interval"), function(x, unit = NULL, ...)
     to.per$month[ndays] <- to.per$month[ndays] - 1
   }
   
-  nmons <- to.per$month < 0
+  nmons <- to.per$month < 0 & !is.na(to.per$month)
   to.per$month[nmons] <- 12 + to.per$month[nmons]
   to.per$year[nmons] <- to.per$year[nmons] - 1
   
@@ -384,7 +453,10 @@ setMethod("as.period", signature(x = "Interval"), function(x, unit = NULL, ...)
 }
 
 setMethod("as.period", signature(x = "Duration"), function(x, unit = NULL, ...) {
-  message("estimate only: convert durations to intervals for accuracy")
+  verbose <- getOption("lubridate.verbose")
+  if (is.null(verbose) || verbose) {
+    message("estimate only: convert durations to intervals for accuracy")
+  }
   span <- x@.Data
   remainder <- abs(span)
   newper <- new_period(second = rep(0, length(x)))
@@ -406,6 +478,10 @@ setMethod("as.period", signature(x = "Duration"), function(x, unit = NULL, ...)
 
 setMethod("as.period", signature("Period"), function(x, unit = NULL, ...) x)
 
+setMethod("as.period", signature("logical"), function(x, unit = NULL, ...) {
+  as.period(as.numeric(x), unit, ...)
+})
+
 #' @export
 setGeneric("as.difftime")
 
@@ -456,4 +532,19 @@ setMethod("as.numeric", signature(x = "Period"), function(x, units = "second", .
 })
 
 
-as.POSIXt <- function(x) as.POSIXlt(x)
\ No newline at end of file
+as.POSIXt <- function(x) as.POSIXlt(x)
+
+#' @export
+setMethod("as.character", signature(x = "Period"), function(x, ...){
+  format(x)
+})
+
+#' @export
+setMethod("as.character", signature(x = "Duration"), function(x, ...){
+  format(x)
+})
+
+#' @export
+setMethod("as.character", signature(x = "Interval"), function(x, ...){
+  format(x)
+})
