@@ -121,4 +121,71 @@ test_that("format.Duration correctly displays intervals of length 0", {
   dur <- new_duration(seconds = 5)
   
   expect_output(dur[FALSE], "Duration\\(0)")
+})
+
+test_that("format.Duration correctly displays durations with an NA", {
+  dur <- new_duration(seconds = c(5, NA))
+  
+  expect_equivalent(format(dur), c("5s", NA))
+})
+
+test_that("summary.Duration creates useful summary", {
+  dur <- dminutes(5)
+  text <- c(rep("300s (~5 minutes)", 6), 1)
+  names(text) <- c("Min.", "1st Qu.", "Median", "Mean", "3rd Qu.", "Max.", "NA's")
+  
+  expect_equal(summary(c(dur, NA)), text)
+})
+
+test_that("compute_estimate works with NA values", {
+  x <- list(
+    NA,
+    c(1, NA),
+    c(100, NA),
+    c(10000, NA),
+    c(100000, NA),
+    c(100000000, NA)
+  )
+  expected <- list(
+    "NA seconds",
+    c("1 seconds", "NA seconds"),
+    c("~1.67 minutes", "NA minutes"),
+    c("~2.78 hours", "NA hours"),
+    c("~1.16 days", "NA days"),
+    c("~3.17 years", "NA years")
+  )
+  mapply(function(x, expected) {
+      expect_identical(expected, lubridate:::compute_estimate(x))
+    },
+    x, expected)
+})
+
+test_that("as.duration handles NA interval objects", {
+  one_missing_date <- as.POSIXct(NA_real_, origin = origin)
+  one_missing_interval <- new_interval(one_missing_date, 
+                                       one_missing_date)
+  several_missing_dates <- rep(as.POSIXct(NA_real_, origin = origin), 2)
+  several_missing_intervals <- new_interval(several_missing_dates, 
+                                            several_missing_dates)
+  start_missing_intervals <- new_interval(several_missing_dates, origin)
+  end_missing_intervals <- new_interval(origin, several_missing_dates)
+  na.dur <- dseconds(NA)
+  
+  expect_equal(as.duration(one_missing_interval), na.dur)
+  expect_equal(as.duration(several_missing_intervals), c(na.dur, na.dur))
+  expect_equal(as.duration(start_missing_intervals), c(na.dur, na.dur))
+  expect_equal(as.duration(end_missing_intervals), c(na.dur, na.dur))
+})
+
+test_that("as.duration handles NA period objects", {
+  na.dur <- dseconds(NA)
+  
+  expect_equal(suppressMessages(as.duration(years(NA))), na.dur)
+  expect_equal(suppressMessages(as.duration(years(c(NA, NA)))), c(na.dur, na.dur))
+  expect_equal(suppressMessages(as.duration(years(c(1, NA)))), c(dyears(1), na.dur))
+})
+
+test_that("as.duration handles NA objects", { 
+  na.dur <- dseconds(NA)
+  expect_equal(as.duration(NA), na.dur)
 })
\ No newline at end of file
